@@ -2,3 +2,6 @@
 ; unittest pack
 (tl-load "unittest")
 (compile-file "unittest.lisp")
+; copy pack
+(tl-load "copy")
+(compile-file "copy.lisp")
